@@ -1,4 +1,8 @@
 package Catalyst::Action::RenderView::ErrorHandler::Action;
+our $VERSION = '0.100090';
+
+
+#ABSTRACT: A Role for any actions that want to react to errors.
 
 use strict;
 use warnings;
@@ -10,11 +14,18 @@ requires 'perform';
 
 1;
 
-__END__
+
+
+
+=pod
 
 =head1 NAME
 
-Catalyst::Action::RenderView::ErrorHandler::Action
+Catalyst::Action::RenderView::ErrorHandler::Action - A Role for any actions that want to react to errors.
+
+=head1 VERSION
+
+version 0.100090
 
 =head1 DESCRIPTION
 
@@ -23,7 +34,7 @@ A Role that should be consumed by actions that are implemented
 =head1 SYNOPSIS
 
     use Moose;
-    
+
     with 'Catalyst::Action::RenderView::ErrorHandler::Action';
 
 =head1 INTERFACE
@@ -52,6 +63,18 @@ Inherited from L<Moose>
 
 =head1 AUTHOR
 
-Andreas Marienborg C<<andreas@startsiden.no>>
+  Andreas Marienborg <andremar@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Andreas Marienborg.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut 
 
 
+
+__END__
+
