@@ -1,4 +1,8 @@
 package Catalyst::Action::RenderView::ErrorHandler::Action::Log;
+our $VERSION = '0.100090';
+
+
+#ABSTRACT: A logging action for errors.
 
 use strict;
 use warnings;
@@ -20,11 +24,18 @@ sub perform {
 
 1;
 
-__END__
+
+
+
+=pod
 
 =head1 NAME
 
-Catalyst::Action::RenderView::ErrorHandler::Action::Log
+Catalyst::Action::RenderView::ErrorHandler::Action::Log - A logging action for errors.
+
+=head1 VERSION
+
+version 0.100090
 
 =head1 DESCRIPTION
 
@@ -75,5 +86,18 @@ Inherited from Moose.
 
 =head1 AUTHOR
 
-Andreas Marienborg C<<andreas@startsiden.no>>
+  Andreas Marienborg <andremar@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Andreas Marienborg.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut 
+
+
+
+__END__
 
