@@ -1,4 +1,11 @@
 package TestApp::View::Default;
+our $VERSION = '0.100090';
+
+
+
+use MRO::Compat;
+use warnings;
+use strict;
 
 use base qw( Catalyst::View::TT );
 
@@ -10,7 +17,7 @@ sub process {
         
     }
     
-    $self->NEXT::process($c);
+    $self->maybe::next::method($c);
 }
 
 1;
\ No newline at end of file
